@@ -2,8 +2,8 @@
 
 module.exports = function( grunt ) {
 	function readOptionalJSON( filepath ) {
-		var stripJSONComments = require( "strip-json-comments" ),
-			data = {};
+		const stripJSONComments = require( "strip-json-comments" );
+		let data = {};
 		try {
 			data = JSON.parse( stripJSONComments(
 				fs.readFileSync( filepath, { encoding: "utf8" } )
@@ -12,29 +12,43 @@ module.exports = function( grunt ) {
 		return data;
 	}
 
-	// Support: Node.js <12
-	// Skip running tasks that dropped support for Node.js 10
-	// in this Node version.
+	const fs = require( "fs" );
+	const { spawn } = require( "child_process" );
+	const gzip = require( "gzip-js" );
+	const nodeV16OrNewer = !/^v1[0-5]\./.test( process.version );
+	const nodeV17OrNewer = !/^v1[0-6]\./.test( process.version );
+	const customBrowsers = process.env.BROWSERS && process.env.BROWSERS.split( "," );
+
+	// Support: Node.js <16
+	// Skip running tasks that dropped support for old Node.js in these Node versions.
 	function runIfNewNode( task ) {
-		return oldNode ? "print_old_node_message:" + task : task;
+		return nodeV16OrNewer ? task : "print_old_node_message:" + task;
 	}
 
-	var fs = require( "fs" ),
-		gzip = require( "gzip-js" ),
-		oldNode = /^v10\./.test( process.version ),
-		nodeV17OrNewer = !/^v1[0246]\./.test( process.version ),
-		isCi = process.env.GITHUB_ACTION,
-		ciBrowsers = process.env.BROWSERS && process.env.BROWSERS.split( "," );
+	if ( nodeV16OrNewer ) {
+		const playwright = require( "playwright-webkit" );
+		process.env.WEBKIT_HEADLESS_BIN = playwright.webkit.executablePath();
+	}
 
 	if ( !grunt.option( "filename" ) ) {
 		grunt.option( "filename", "jquery.js" );
 	}
 
+	const builtJsFiles = [
+		"dist/jquery.js",
+		"dist/jquery.min.js",
+		"dist/jquery.slim.js",
+		"dist/jquery.slim.min.js"
+	];
+
+	const builtJsMinFiles = builtJsFiles
+		.filter( filepath => filepath.endsWith( ".min.js" ) );
+
 	grunt.initConfig( {
 		pkg: grunt.file.readJSON( "package.json" ),
 		dst: readOptionalJSON( "dist/.destination.json" ),
-		"compare_size": {
-			files: [ "dist/jquery.js", "dist/jquery.min.js" ],
+		compare_size: {
+			files: builtJsMinFiles,
 			options: {
 				compress: {
 					gz: function( contents ) {
@@ -61,8 +75,7 @@ module.exports = function( grunt ) {
 			all: {
 				dest: "dist/jquery.js",
 				minimum: [
-					"core",
-					"selector"
+					"core"
 				],
 
 				// Exclude specified modules if the module matching the key is removed
@@ -76,7 +89,7 @@ module.exports = function( grunt ) {
 						include: [ "core/ready-no-deferred" ]
 					},
 					event: [ "deprecated/ajax-event-alias", "deprecated/event" ],
-					sizzle: [ "css/hiddenVisibleSelectors", "effects/animatedSelector" ]
+					selector: [ "css/hiddenVisibleSelectors", "effects/animatedSelector" ]
 				}
 			}
 		},
@@ -86,8 +99,9 @@ module.exports = function( grunt ) {
 					destPrefix: "external"
 				},
 				files: {
-					"sizzle/dist": "sizzle/dist",
-					"sizzle/LICENSE.txt": "sizzle/LICENSE.txt",
+					"bootstrap/bootstrap.css": "bootstrap/dist/css/bootstrap.css",
+					"bootstrap/bootstrap.min.css": "bootstrap/dist/css/bootstrap.min.css",
+					"bootstrap/bootstrap.min.css.map": "bootstrap/dist/css/bootstrap.min.css.map",
 
 					"core-js/core-js.js": "core-js/client/core.min.js",
 					"core-js/LICENSE.txt": "core-js/LICENSE",
@@ -120,7 +134,7 @@ module.exports = function( grunt ) {
 			// We have to explicitly declare "src" property otherwise "newer"
 			// task wouldn't work properly :/
 			dist: {
-				src: [ "dist/jquery.js", "dist/jquery.min.js" ]
+				src: builtJsFiles
 			},
 			dev: {
 				src: [ "src/**/*.js", "Gruntfile.js", "test/**/*.js", "build/**/*.js" ]
@@ -232,10 +246,11 @@ module.exports = function( grunt ) {
 				singleRun: true
 			},
 			main: {
-				browsers: isCi && ciBrowsers || [ "ChromeHeadless", "FirefoxHeadless" ]
+				browsers: customBrowsers ||
+					[ "ChromeHeadless", "FirefoxHeadless", "WebkitHeadless" ]
 			},
 			amd: {
-				browsers: isCi && ciBrowsers || [ "ChromeHeadless" ],
+				browsers: customBrowsers || [ "ChromeHeadless" ],
 				options: {
 					client: {
 						qunit: {
@@ -303,7 +318,7 @@ module.exports = function( grunt ) {
 		uglify: {
 			all: {
 				files: {
-					"dist/<%= grunt.option('filename').replace('.js', '.min.js') %>":
+					"dist/<%= grunt.option('filename').replace(/\\.js$/, '.min.js') %>":
 						"dist/<%= grunt.option('filename') %>"
 				},
 				options: {
@@ -337,7 +352,9 @@ module.exports = function( grunt ) {
 	} );
 
 	// Load grunt tasks from NPM packages
-	require( "load-grunt-tasks" )( grunt );
+	require( "load-grunt-tasks" )( grunt, {
+		pattern: nodeV16OrNewer ? [ "grunt-*" ] : [ "grunt-*", "!grunt-eslint" ]
+	} );
 
 	// Integrate jQuery specific tasks
 	grunt.loadTasks( "build/tasks" );
@@ -347,6 +364,20 @@ module.exports = function( grunt ) {
 		grunt.log.writeln( "Old Node.js detected, running the task \"" + task + "\" skipped..." );
 	} );
 
+	grunt.registerTask( "build-all-variants",
+		"Build both the full & slim builds",
+		function() {
+			const done = this.async();
+
+			spawn( "npm run build-all-variants", {
+				stdio: "inherit",
+				shell: true
+			} )
+				.on( "close", code => {
+					done( code === 0 );
+				} );
+		} );
+
 	grunt.registerTask( "print_jsdom_message", () => {
 		grunt.log.writeln( "Node.js 17 or newer detected, skipping jsdom tests..." );
 	} );
@@ -370,7 +401,7 @@ module.exports = function( grunt ) {
 		runIfNewNode( "newer:eslint:dist" )
 	] );
 
-	grunt.registerTask( "test:fast", runIfNewNode( "node_smoke_tests" ) );
+	grunt.registerTask( "test:fast", [ "node_smoke_tests" ] );
 	grunt.registerTask( "test:slow", [
 		runIfNewNode( "promises_aplus_tests" ),
 
@@ -403,10 +434,7 @@ module.exports = function( grunt ) {
 
 	grunt.registerTask( "default", [
 		runIfNewNode( "eslint:dev" ),
-		"build:*:*",
-		"uglify",
-		"remove_map_comment",
-		"dist:*",
+		"build-all-variants",
 		"test:prepare",
 		runIfNewNode( "eslint:dist" ),
 		"test:fast",
