@@ -368,7 +368,7 @@ QUnit.module( "ajax", {
 		};
 	} );
 
-	ajaxTest( "jQuery.ajax() - URL fragment component preservation", 4, function( assert ) {
+	ajaxTest( "jQuery.ajax() - URL fragment component preservation", 5, function( assert ) {
 		return [
 			{
 				url: baseURL + "name.html#foo",
@@ -400,6 +400,25 @@ QUnit.module( "ajax", {
 				},
 				error: true
 			},
+			{
+				url: baseURL + "name.html?abc#foo",
+				data: [
+					{
+						name: "test",
+						value: 123
+					},
+					{
+						name: "devo",
+						value: "hat"
+					}
+				],
+				beforeSend: function( xhr, settings ) {
+					assert.equal( settings.url, baseURL + "name.html?abc&test=123&devo=hat#foo",
+						"hash preserved for request with query component and array data." );
+					return false;
+				},
+				error: true
+			},
 			{
 				url: baseURL + "name.html?abc#brownies",
 				data: {
@@ -1356,43 +1375,92 @@ QUnit.module( "ajax", {
 		];
 	} );
 
-	ajaxTest( "jQuery.ajax() - JSON by content-type", 5, function( assert ) {
-		return {
-			url: baseURL + "mock.php?action=json",
-			data: {
-				"header": "json",
-				"array": "1"
+	ajaxTest( "jQuery.ajax() - JSON by content-type", 10, function( assert ) {
+		return [
+			{
+				url: baseURL + "mock.php?action=json",
+				data: {
+					"header": "json",
+					"array": "1"
+				},
+				success: function( json ) {
+					assert.ok( json.length >= 2, "Check length" );
+					assert.strictEqual( json[ 0 ][ "name" ], "John", "Check JSON: first, name" );
+					assert.strictEqual( json[ 0 ][ "age" ], 21, "Check JSON: first, age" );
+					assert.strictEqual( json[ 1 ][ "name" ], "Peter", "Check JSON: second, name" );
+					assert.strictEqual( json[ 1 ][ "age" ], 25, "Check JSON: second, age" );
+				}
 			},
-			success: function( json ) {
-				assert.ok( json.length >= 2, "Check length" );
-				assert.strictEqual( json[ 0 ][ "name" ], "John", "Check JSON: first, name" );
-				assert.strictEqual( json[ 0 ][ "age" ], 21, "Check JSON: first, age" );
-				assert.strictEqual( json[ 1 ][ "name" ], "Peter", "Check JSON: second, name" );
-				assert.strictEqual( json[ 1 ][ "age" ], 25, "Check JSON: second, age" );
+			{
+				url: baseURL + "mock.php?action=json",
+				data: [
+					{
+						name: "header",
+						value: "json"
+					},
+					{
+						name: "array",
+						value: "1"
+					}
+				],
+				success: function( json ) {
+					assert.ok( json.length >= 2, "Check length" );
+					assert.strictEqual( json[ 0 ][ "name" ], "John", "Check JSON: first, name" );
+					assert.strictEqual( json[ 0 ][ "age" ], 21, "Check JSON: first, age" );
+					assert.strictEqual( json[ 1 ][ "name" ], "Peter", "Check JSON: second, name" );
+					assert.strictEqual( json[ 1 ][ "age" ], 25, "Check JSON: second, age" );
+				}
 			}
-		};
+		];
 	} );
 
-	ajaxTest( "jQuery.ajax() - JSON by content-type disabled with options", 6, function( assert ) {
-		return {
-			url: url( "mock.php?action=json" ),
-			data: {
-				"header": "json",
-				"array": "1"
+	ajaxTest( "jQuery.ajax() - JSON by content-type disabled with options", 12, function( assert ) {
+		return [
+			{
+				url: url( "mock.php?action=json" ),
+				data: {
+					"header": "json",
+					"array": "1"
+				},
+				contents: {
+					"json": false
+				},
+				success: function( text ) {
+					assert.strictEqual( typeof text, "string", "json wasn't auto-determined" );
+					var json = JSON.parse( text );
+					assert.ok( json.length >= 2, "Check length" );
+					assert.strictEqual( json[ 0 ][ "name" ], "John", "Check JSON: first, name" );
+					assert.strictEqual( json[ 0 ][ "age" ], 21, "Check JSON: first, age" );
+					assert.strictEqual( json[ 1 ][ "name" ], "Peter", "Check JSON: second, name" );
+					assert.strictEqual( json[ 1 ][ "age" ], 25, "Check JSON: second, age" );
+				}
 			},
-			contents: {
-				"json": false
-			},
-			success: function( text ) {
-				assert.strictEqual( typeof text, "string", "json wasn't auto-determined" );
-				var json = JSON.parse( text );
-				assert.ok( json.length >= 2, "Check length" );
-				assert.strictEqual( json[ 0 ][ "name" ], "John", "Check JSON: first, name" );
-				assert.strictEqual( json[ 0 ][ "age" ], 21, "Check JSON: first, age" );
-				assert.strictEqual( json[ 1 ][ "name" ], "Peter", "Check JSON: second, name" );
-				assert.strictEqual( json[ 1 ][ "age" ], 25, "Check JSON: second, age" );
+			{
+				url: url( "mock.php?action=json" ),
+				data: [
+					{
+						name: "header",
+						value: "json"
+					},
+					{
+						name: "array",
+						value: "1"
+					}
+				],
+				contents: {
+					"json": false
+				},
+				success: function( text ) {
+					assert.strictEqual( typeof text, "string", "json wasn't auto-determined" );
+					var json = JSON.parse( text );
+					assert.ok( json.length >= 2, "Check length" );
+					assert.strictEqual( json[ 0 ][ "name" ], "John", "Check JSON: first, name" );
+					assert.strictEqual( json[ 0 ][ "age" ], 21, "Check JSON: first, age" );
+					assert.strictEqual( json[ 1 ][ "name" ], "Peter", "Check JSON: second, name" );
+					assert.strictEqual( json[ 1 ][ "age" ], 25, "Check JSON: second, age" );
+				}
 			}
-		};
+		];
 	} );
 
 	ajaxTest( "jQuery.ajax() - simple get", 1, function( assert ) {
@@ -1440,18 +1508,36 @@ QUnit.module( "ajax", {
 		};
 	} );
 
-	ajaxTest( "jQuery.ajax() - data - text/plain (gh-2658)", 1, function( assert ) {
-		return {
-			url: "bogus.html",
-			data: { devo: "A Beautiful World" },
-			type: "post",
-			contentType: "text/plain",
-			beforeSend: function( _, s ) {
-				assert.strictEqual( s.data, "devo=A%20Beautiful%20World", "data is %20-encoded" );
-				return false;
+	ajaxTest( "jQuery.ajax() - data - text/plain (gh-2658)", 2, function( assert ) {
+		return [
+			{
+				url: "bogus.html",
+				data: { devo: "A Beautiful World" },
+				type: "post",
+				contentType: "text/plain",
+				beforeSend: function( _, s ) {
+					assert.strictEqual( s.data, "devo=A%20Beautiful%20World", "data is %20-encoded" );
+					return false;
+				},
+				error: true
 			},
-			error: true
-		};
+			{
+				url: "bogus.html",
+				data: [
+					{
+						name: "devo",
+						value: "A Beautiful World"
+					}
+				],
+				type: "post",
+				contentType: "text/plain",
+				beforeSend: function( _, s ) {
+					assert.strictEqual( s.data, "devo=A%20Beautiful%20World", "data is %20-encoded" );
+					return false;
+				},
+				error: true
+			}
+		];
 	} );
 
 	ajaxTest( "jQuery.ajax() - don't escape %20 with contentType override (gh-4119)", 1, function( assert ) {
@@ -1500,34 +1586,82 @@ QUnit.module( "ajax", {
 		};
 	} );
 
-	ajaxTest( "jQuery.ajax() - data - no processing POST", 1, function( assert ) {
-		return {
-			url: "bogus.html",
-			data: { devo: "A Beautiful World" },
-			type: "post",
-			contentType: "x-special-sauce",
-			processData: false,
-			beforeSend: function( _, s ) {
-				assert.deepEqual( s.data, { devo: "A Beautiful World" }, "data is not processed" );
-				return false;
+	ajaxTest( "jQuery.ajax() - data - no processing POST", 2, function( assert ) {
+		return [
+			{
+				url: "bogus.html",
+				data: { devo: "A Beautiful World" },
+				type: "post",
+				contentType: "x-special-sauce",
+				processData: false,
+				beforeSend: function( _, s ) {
+					assert.deepEqual( s.data, { devo: "A Beautiful World" }, "data is not processed" );
+					return false;
+				},
+				error: true
 			},
-			error: true
-		};
+			{
+				url: "bogus.html",
+				data: [
+					{
+						name: "devo",
+						value: "A Beautiful World"
+					}
+				],
+				type: "post",
+				contentType: "x-special-sauce",
+				processData: false,
+				beforeSend: function( _, s ) {
+					assert.deepEqual( s.data, [
+						{
+							name: "devo",
+							value: "A Beautiful World"
+						}
+					], "data is not processed" );
+					return false;
+				},
+				error: true
+			}
+		];
 	} );
 
-	ajaxTest( "jQuery.ajax() - data - no processing GET", 1, function( assert ) {
-		return {
-			url: "bogus.html",
-			data: { devo: "A Beautiful World" },
-			type: "get",
-			contentType: "x-something-else",
-			processData: false,
-			beforeSend: function( _, s ) {
-				assert.deepEqual( s.data, { devo: "A Beautiful World" }, "data is not processed" );
-				return false;
+	ajaxTest( "jQuery.ajax() - data - no processing GET", 2, function( assert ) {
+		return [
+			{
+				url: "bogus.html",
+				data: { devo: "A Beautiful World" },
+				type: "get",
+				contentType: "x-something-else",
+				processData: false,
+				beforeSend: function( _, s ) {
+					assert.deepEqual( s.data, { devo: "A Beautiful World" }, "data is not processed" );
+					return false;
+				},
+				error: true
 			},
-			error: true
-		};
+			{
+				url: "bogus.html",
+				data: [
+					{
+						name: "devo",
+						value: "A Beautiful World"
+					}
+				],
+				type: "get",
+				contentType: "x-something-else",
+				processData: false,
+				beforeSend: function( _, s ) {
+					assert.deepEqual( s.data, [
+						{
+							name: "devo",
+							value: "A Beautiful World"
+						}
+					], "data is not processed" );
+					return false;
+				},
+				error: true
+			}
+		];
 	} );
 
 		ajaxTest( "jQuery.ajax() - data - process string with GET", 2, function( assert ) {
@@ -1640,8 +1774,14 @@ QUnit.module( "ajax", {
 		var done = assert.async();
 		jQuery.ajax( url( "mock.php?action=status&code=200&text=Hello" ) ).done( function( _, statusText, jqXHR ) {
 			assert.strictEqual( statusText, "success", "callback status text ok for success" );
-			assert.ok( [ "Hello", "OK", "success" ].indexOf( jqXHR.statusText ) > -1,
+
+			// Support: iOS 9 only
+			// Some versions of iOS 9 return the "HTTP/2.0 200" status text
+			// in this case; accept it.
+			assert.ok(
+				[ "Hello", "OK", "success", "HTTP/2.0 200" ].indexOf( jqXHR.statusText ) > -1,
 				"jqXHR status text ok for success (" + jqXHR.statusText + ")" );
+
 			jQuery.ajax( url( "mock.php?action=status&code=404&text=World" ) ).fail( function( jqXHR, statusText ) {
 				assert.strictEqual( statusText, "error", "callback status text ok for error" );
 				done();
@@ -2195,7 +2335,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
 	// Safari 13 did similar changes. The below check will catch them both.
 	// Edge Legacy fakes Chrome which fakes Safari in their user agents so we need
 	// to exclude Edge specifically here so that the test continues to run there.
-	if ( !/safari/i.test( navigator.userAgent ) || /edge\//i.test( navigator.userAgent ) ) {
+	if ( !/webkit/i.test( navigator.userAgent ) || /edge\//i.test( navigator.userAgent ) ) {
 		testIframe(
 			"trac-14379 - jQuery.ajax() on unload",
 			"ajax/onunload.html",
@@ -2446,7 +2586,7 @@ if ( typeof window.ArrayBuffer === "undefined" || typeof new XMLHttpRequest().re
 	} );
 
 	QUnit.test(
-		"jQuery#load() - always use GET method even if it overrided through ajaxSetup (trac-11264)",
+		"jQuery#load() - always use GET method even if overridden through ajaxSetup (trac-11264)",
 		function( assert ) {
 			assert.expect( 1 );
 			var done = assert.async();
