@@ -965,7 +965,7 @@ QUnit.test( "show/hide 3.0, inline hidden", function( assert ) {
 	} );
 } );
 
-QUnit[ jQuery.find.compile && jQuery.fn.toggle ? "test" : "skip" ]( "toggle()", function( assert ) {
+QUnit[ QUnit.jQuerySelectors && jQuery.fn.toggle ? "test" : "skip" ]( "toggle()", function( assert ) {
 	assert.expect( 9 );
 	var div, oldHide,
 		x = jQuery( "#foo" );
@@ -998,7 +998,7 @@ QUnit[ jQuery.find.compile && jQuery.fn.toggle ? "test" : "skip" ]( "toggle()",
 	jQuery.fn.hide = oldHide;
 } );
 
-QUnit[ jQuery.find.compile && jQuery.fn.toggle ? "test" : "skip" ]( "detached toggle()", function( assert ) {
+QUnit[ QUnit.jQuerySelectors && jQuery.fn.toggle ? "test" : "skip" ]( "detached toggle()", function( assert ) {
 	assert.expect( 6 );
 	var detached = jQuery( "<p><a></a><p>" ).find( "*" ).addBack(),
 		hiddenDetached = jQuery( "<p><a></a></p>" ).find( "*" ).addBack().css( "display", "none" ),
@@ -1022,12 +1022,14 @@ QUnit[ jQuery.find.compile && jQuery.fn.toggle ? "test" : "skip" ]( "detached to
 		"cascade-hidden element in detached tree" );
 } );
 
-QUnit[ jQuery.find.compile && jQuery.fn.toggle &&
+QUnit[ QUnit.jQuerySelectors && jQuery.fn.toggle &&
 	document.body.attachShadow && document.body.getRootNode ?
 		"test" :
 		"skip"
 ]( "shadow toggle()", function( assert ) {
+
 	assert.expect( 4 );
+
 	jQuery( "<div id='shadowHost'></div>" ).appendTo( "#qunit-fixture" );
 	var shadowHost = document.querySelector( "#shadowHost" );
 	var shadowRoot = shadowHost.attachShadow( { mode: "open" } );
@@ -1200,30 +1202,102 @@ if ( includesModule( "offset" ) ) {
 	} );
 }
 
-QUnit.test( "Do not append px (trac-9548, trac-12990, gh-2792)", function( assert ) {
-	assert.expect( 3 );
+QUnit.test( "Do not append px (trac-9548, trac-12990, gh-2792, gh-5179)", function( assert ) {
+	assert.expect( 10 );
 
-	var $div = jQuery( "<div>" ).appendTo( "#qunit-fixture" );
+	var $div = jQuery( "<div>" ),
+		$svg = jQuery(
+			"<svg xmlns='http://www.w3.org/2000/svg' width='200' height='200'>" +
+			"	<path d=\" M 2,2 h 2\"></path>" +
+			"</svg>"
+		),
+		$svgPath = $svg.find( "path" );
 
-	$div.css( "fill-opacity", 1 );
+	jQuery( "#qunit-fixture" )
+		.append( $div )
+		.append( $svg );
 
-	assert.equal( $div.css( "fill-opacity" ), 1, "Do not append px to 'fill-opacity'" );
-
-	$div.css( "column-count", 1 );
-	if ( $div.css( "column-count" ) !== undefined ) {
-		assert.equal( $div.css( "column-count" ), 1, "Do not append px to 'column-count'" );
-	} else {
-		assert.ok( true, "No support for column-count CSS property" );
-	}
+	// HTML
 
 	$div.css( "animation-iteration-count", 2 );
 	if ( $div.css( "animation-iteration-count" ) !== undefined ) {
-		// if $div.css( "animation-iteration-count" ) return "1",
-		// it actually return the default value of animation-iteration-count
-		assert.equal( $div.css( "animation-iteration-count" ), 2, "Do not append px to 'animation-iteration-count'" );
+		// if $div.css( "animation-iteration-count" ) returns "1",
+		// it actually returns the default value of animation-iteration-count
+		assert.equal( $div.css( "animation-iteration-count" ), "2",
+			"Does not append px to 'animation-iteration-count'" );
 	} else {
-		assert.ok( true, "No support for animation-iteration-count CSS property" );
+		assert.ok( true, "No support for 'animation-iteration-count' CSS property" );
 	}
+
+	// Support: Safari <15 only, iOS <15 only
+	// Older Safari doesn't support 'aspect-ratio' but it supports a non-standard
+	// 'WebkitAspectRatio' which interferes with this test.
+	if ( $div.css( "-webkit-aspect-ratio" ) !== "auto" ) {
+		$div.css( "aspect-ratio", 2 );
+		window.div = $div[ 0 ];
+		if ( $div.css( "aspect-ratio" ) !== undefined ) {
+			assert.equal( $div.css( "aspect-ratio" ), "2 / 1",
+				"Does not append px to 'aspect-ratio'" );
+		} else {
+			assert.ok( true, "No support for 'aspect-ratio' CSS property" );
+		}
+	} else {
+		assert.ok( true, "No support for 'aspect-ratio' CSS property (WebKit)" );
+	}
+
+	$div.css( "border-image-slice", 2 );
+	if ( $div.css( "border-image-slice" ) !== undefined &&
+
+			// Support: Firefox <=48-54 only
+			// Older Firefox serializes 'border-image-slice' differently.
+			!/firefox\/48\./i.test( navigator.userAgent ) ) {
+		assert.equal( $div.css( "border-image-slice" ), "2",
+			"Does not append px to 'border-image-slice'" );
+	} else {
+		assert.ok( true, "No or broken support for 'border-image-slice' CSS property" );
+	}
+
+	$div.css( "column-count", 1 );
+	if ( $div.css( "column-count" ) !== undefined ) {
+		assert.equal( $div.css( "column-count" ), "1",
+			"Does not append px to 'column-count'" );
+	} else {
+		assert.ok( true, "No support for 'column-count' CSS property" );
+	}
+
+	$div.css( "scale", 2 );
+	if ( $div.css( "scale" ) !== undefined ) {
+		assert.equal( $div.css( "scale" ), "2", "Does not append px to 'scale'" );
+	} else {
+		assert.ok( true, "No support for 'scale' CSS property" );
+	}
+
+	// SVG
+
+	$svgPath.css( "fill-opacity", 0.5 );
+	assert.equal( $svgPath.css( "fill-opacity" ), "0.5",
+		"Does not append px to 'fill-opacity'" );
+
+	$svgPath.css( "flood-opacity", 0.5 );
+	if ( $svgPath.css( "flood-opacity" ) !== undefined ) {
+		assert.equal( $svgPath.css( "flood-opacity" ), "0.5",
+			"Does not append px to 'flood-opacity'" );
+	} else {
+		assert.ok( true, "No support for 'flood-opacity' CSS property" );
+	}
+
+	$svgPath.css( "stop-opacity", 0.5 );
+	assert.equal( $svgPath.css( "stop-opacity" ), "0.5",
+		"Does not append px to 'stop-opacity'" );
+
+	$svgPath.css( "stroke-miterlimit", 1.5 );
+	assert.equal( $svgPath.css( "stroke-miterlimit" ), "1.5",
+		"Does not append px to 'stroke-miterlimit'" );
+
+	$svgPath.css( "stroke-opacity", 0.5 );
+	assert.equal( $svgPath.css( "stroke-opacity" ), "0.5",
+		"Does not append px to 'stroke-opacity'" );
+
 } );
 
 
@@ -1372,13 +1446,13 @@ testIframe(
 	} );
 } )();
 
-QUnit.test( "certain css values of 'normal' should be convertable to a number, see trac-8627", function( assert ) {
+QUnit.test( "certain css values of 'normal' should be convertible to a number, see trac-8627", function( assert ) {
 	assert.expect( 3 );
 
 	var el = jQuery( "<div style='letter-spacing:normal;font-weight:normal;'>test</div>" ).appendTo( "#qunit-fixture" );
 
-	assert.ok( !isNaN( parseFloat( el.css( "letterSpacing" ) ) ), "css('letterSpacing') not convertable to number, see trac-8627" );
-	assert.ok( !isNaN( parseFloat( el.css( "fontWeight" ) ) ), "css('fontWeight') not convertable to number, see trac-8627" );
+	assert.ok( !isNaN( parseFloat( el.css( "letterSpacing" ) ) ), "css('letterSpacing') not convertible to number, see trac-8627" );
+	assert.ok( !isNaN( parseFloat( el.css( "fontWeight" ) ) ), "css('fontWeight') not convertible to number, see trac-8627" );
 	assert.equal( typeof el.css( "fontWeight" ), "string", ".css() returns a string" );
 } );
 
@@ -1450,7 +1524,7 @@ QUnit.test( "css opacity consistency across browsers (trac-12685)", function( as
 	assert.equal( Math.round( el.css( "opacity" ) * 100 ), 10, "remove opacity override" );
 } );
 
-QUnit[ jQuery.find.compile ? "test" : "skip" ]( ":visible/:hidden selectors", function( assert ) {
+QUnit[ QUnit.jQuerySelectors ? "test" : "skip" ]( ":visible/:hidden selectors", function( assert ) {
 	assert.expect( 17 );
 
 	var $div, $table, $a;
@@ -1486,7 +1560,12 @@ QUnit[ jQuery.find.compile ? "test" : "skip" ]( ":visible/:hidden selectors", fu
 	$table.css( "display", "none" ).html( "<tr><td>cell</td><td>cell</td></tr>" );
 	assert.equal( jQuery( "#table td:visible" ).length, 0, "hidden cell children not perceived as visible (trac-4512)" );
 
-	assert.t( "Is Visible", "#qunit-fixture div:visible:lt(2)", [ "foo", "nothiddendiv" ] );
+	if ( QUnit.jQuerySelectorsPos ) {
+		assert.t( "Is Visible", "#qunit-fixture div:visible:lt(2)", [ "foo", "nothiddendiv" ] );
+	} else {
+		assert.ok( "skip", "Positional selectors are not supported" );
+	}
+
 	assert.t( "Is Not Hidden", "#qunit-fixture:hidden", [] );
 	assert.t( "Is Hidden", "#form input:hidden", [ "hidden1", "hidden2" ] );
 
@@ -1760,6 +1839,8 @@ QUnit.test( "Do not throw on frame elements from css method (trac-15098)", funct
 			"        --prop10:\f\r\n\t val10 \f\r\n\t;\n" +
 			"        --prop11:\u000C\u000D\u000A\u0009\u0020val11\u0020\u0009\u000A\u000D\u000C;\n" +
 			"        --prop12:\u000Bval12\u000B;\n" +
+			"        --space: ;\n" +
+			"        --empty:;\n" +
 			"    }\n" +
 			"</style>"
 		);
@@ -1767,8 +1848,9 @@ QUnit.test( "Do not throw on frame elements from css method (trac-15098)", funct
 		var div = jQuery( "<div>" ).appendTo( "#qunit-fixture" ),
 			$elem = jQuery( "<div>" ).addClass( "test__customProperties" )
 				.appendTo( "#qunit-fixture" ),
-			webkitOrBlink = /\bsafari\b/i.test( navigator.userAgent ),
-			expected = 17;
+			webkitOrBlink = /\webkit\b/i.test( navigator.userAgent ) &&
+				!/edge\//i.test( navigator.userAgent ),
+			expected = 20;
 
 		if ( webkitOrBlink ) {
 			expected -= 2;
@@ -1814,6 +1896,9 @@ QUnit.test( "Do not throw on frame elements from css method (trac-15098)", funct
 		assert.equal( $elem.css( "--prop10" ), "val10", "Multiple preceding and following escaped unicode whitespace trimmed" );
 		assert.equal( $elem.css( "--prop11" ), "val11", "Multiple preceding and following unicode whitespace trimmed" );
 		assert.equal( $elem.css( "--prop12" ), "\u000Bval12\u000B", "Multiple preceding and following non-CSS whitespace reserved" );
+		assert.equal( $elem.css( "--space" ), undefined );
+		assert.equal( $elem.css( "--empty" ), undefined );
+		assert.equal( $elem.css( "--nonexistent" ), undefined );
 	} );
 
 	QUnit[ supportsCssVars ? "test" : "skip" ]( "Don't append px to CSS vars", function( assert ) {
