@@ -97,7 +97,7 @@ QUnit.test( "trigger() shortcuts", function( assert ) {
 } );
 
 if ( includesModule( "ajax" ) ) {
-	ajaxTest( "jQuery.ajax() - events with context", 12, function( assert ) {
+	ajaxTest( "Ajax events aliases (with context)", 12, function( assert ) {
 		var context = document.createElement( "div" );
 
 		function event( e ) {
@@ -113,10 +113,10 @@ if ( includesModule( "ajax" ) ) {
 		return {
 			setup: function() {
 				jQuery( context ).appendTo( "#foo" )
-					.on( "ajaxSend", event )
-					.on( "ajaxComplete", event )
-					.on( "ajaxError", event )
-					.on( "ajaxSuccess", event );
+					.ajaxSend( event )
+					.ajaxComplete( event )
+					.ajaxError( event )
+					.ajaxSuccess( event );
 			},
 			requests: [ {
 				url: url( "name.html" ),
@@ -661,4 +661,43 @@ QUnit.test( "trim", function( assert ) {
 	assert.equal( jQuery.trim( "\uFEFF \xA0! | \uFEFF" ), "! |", "leading/trailing should be trimmed" );
 } );
 
+if ( includesModule( "deferred" ) ) {
+
+	// Support: IE 9 only
+	// Test fails in IE9 but is skipped there because console is not active
+	QUnit[ window.console ? "test" : "skip" ]( "jQuery.Deferred.exceptionHook with stack hooks", function( assert ) {
+
+		assert.expect( 2 );
+
+		var done = assert.async(),
+			defer = jQuery.Deferred(),
+			oldWarn = window.console.warn;
+
+		jQuery.Deferred.getStackHook = function() {
+
+			// Default exceptionHook assumes the stack is in a form console.warn can log,
+			// but a custom getStackHook+exceptionHook pair could save a raw form and
+			// format it to a string only when an exception actually occurs.
+			// For the unit test we just ensure the plumbing works.
+			return "NO STACK FOR YOU";
+		};
+
+		window.console.warn = function() {
+			var msg = Array.prototype.join.call( arguments, " " );
+			assert.ok( /cough_up_hairball/.test( msg ), "Function mentioned: " + msg );
+			assert.ok( /NO STACK FOR YOU/.test( msg ), "Stack trace included: " + msg );
+		};
+
+		defer.then( function() {
+			jQuery.cough_up_hairball();
+		} ).then( null, function() {
+			window.console.warn = oldWarn;
+			delete jQuery.Deferred.getStackHook;
+			done();
+		} );
+
+		defer.resolve();
+	} );
+}
+
 }
